==> haskell-monad-par-extras-0.3.3-128-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-par-extras
version:              0.3.3
visibility:           public
id:                   monad-par-extras-0.3.3-I3db6idFsz1JojkQl47QIh
key:                  monad-par-extras-0.3.3-I3db6idFsz1JojkQl47QIh
license:              BSD-3-Clause
copyright:            (c) Ryan Newton 2012
maintainer:           Ryan Newton <rrnewton@gmail.com>
author:               Ryan Newton, Simon Marlow
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.

category:             Control,Parallelism,Monads
abi:                  b771270fec26d2c8168c0601dd4cce0d
exposed:              True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State

hidden-modules:       Control.Monad.Par.Pedigree
import-dirs:          /usr/lib/ghc-9.0.1/site-local/monad-par-extras-0.3.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/monad-par-extras-0.3.3
hs-libraries:         HSmonad-par-extras-0.3.3-I3db6idFsz1JojkQl47QIh
depends:
    abstract-par-0.3.3-JGpg8odfEz949f1LvZszw6 base-4.15.0.0
    cereal-0.5.8.2-61j1a5W2ABqDRz8HqQdVx7 deepseq-1.4.5.0 mtl-2.2.2
    random-1.2.1-AVlrOvJdpabLt5UKQZGZvR transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock

haddock-html:         /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-extras-0.3.3-129-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-par-extras
version:              0.3.3
visibility:           public
id:                   monad-par-extras-0.3.3-4QqLToMP8fLEqzKXdA23qZ
key:                  monad-par-extras-0.3.3-4QqLToMP8fLEqzKXdA23qZ
license:              BSD-3-Clause
copyright:            (c) Ryan Newton 2012
maintainer:           Ryan Newton <rrnewton@gmail.com>
author:               Ryan Newton, Simon Marlow
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             Combinators and extra features for Par monads
description:
    The modules below provide additional
    data structures, and other added capabilities
    layered on top of the '\''Par'\'' monad.

category:             Control,Parallelism,Monads
abi:                  af3484cce5053870972eff3ba8e98338
exposed:              True
exposed-modules:
    Control.Monad.Par.AList Control.Monad.Par.Combinator
    Control.Monad.Par.RNG Control.Monad.Par.State

hidden-modules:       Control.Monad.Par.Pedigree
import-dirs:          /usr/lib/ghc-9.0.1/site-local/monad-par-extras-0.3.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/monad-par-extras-0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/monad-par-extras-0.3.3
hs-libraries:         HSmonad-par-extras-0.3.3-4QqLToMP8fLEqzKXdA23qZ
depends:
    abstract-par-0.3.3-JGpg8odfEz949f1LvZszw6 base-4.15.0.0
    cereal-0.5.8.2-61j1a5W2ABqDRz8HqQdVx7 deepseq-1.4.5.0 mtl-2.2.2
    random-1.2.1-Iy7yOfCz74T6VyvkhFUFfX transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-par-extras/html/monad-par-extras.haddock

haddock-html:         /usr/share/doc/haskell-monad-par-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
